basic_commands
open | /demo/basic_commands.html |
assertText | demo | KSS
assertText | copy | copy here
click | change |
waitForElementPresent | workedagain |
assertElementPresent | workedagain |
assertText | demo | it worked again
click | clear |
waitForElementNotPresent | workedagain |
assertNotText | demo | it worked again
click | copyFrom |
waitForNotText | copy | copy here
assertNotText | copy | copy here
assertElementNotPresent | workedagain |
click | change |
waitForElementPresent | workedagain |
assertElementPresent | workedagain |
assertNotText | copy | it worked again
click | copyFrom |
waitForText | copy | it worked again
assertText | copy | it worked again
click | clear |
waitForNotText | demo | it worked again
assertNotText | demo | it worked again
click | copyTo |
waitForText | demo | it worked again
assertText | demo | it worked again
click | clear |
waitForNotText | demo | it worked again
assertNotText | demo | it worked again
click | moveTo |
waitForText | demo | it worked again
assertText | demo | it worked again
assertNotText | copy | it worked again